==> haskell-crypto-cipher-types-0.0.9-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-crypto-cipher-types.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: crypto-cipher-types
version: 0.0.9
id: crypto-cipher-types-0.0.9-D0DdUwYNchw8RAl6A55EMq
key: crypto-cipher-types-0.0.9-D0DdUwYNchw8RAl6A55EMq
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: vincent@snarc.org
stability: experimental
homepage: http://github.com/vincenthz/hs-crypto-cipher
synopsis: Generic cryptography cipher types
description:
    Generic cryptography cipher types
category: Cryptography
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Crypto.Cipher.Types Crypto.Cipher.Types.Unsafe
hidden-modules: Crypto.Cipher.Types.GF Crypto.Cipher.Types.Block
                Crypto.Cipher.Types.BlockIO Crypto.Cipher.Types.Stream
                Crypto.Cipher.Types.OfIO Crypto.Cipher.Types.AEAD
                Crypto.Cipher.Types.Base Crypto.Cipher.Types.Utils
abi: 648c45a050fdb8c45242c6c81bb98d8e
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/crypto-cipher-types-0.0.9
library-dirs: /usr/lib/ghc-8.0.1/site-local/crypto-cipher-types-0.0.9
data-dir: /usr/share/arm-linux-ghc-8.0.1/crypto-cipher-types-0.0.9
hs-libraries: HScrypto-cipher-types-0.0.9-D0DdUwYNchw8RAl6A55EMq
depends:
    base-4.9.0.0 byteable-0.1.1-15aIBCArSOBEnGxArzrDTM
    bytestring-0.10.8.1 securemem-0.1.9-HztgpoIdC1f7G9KSDGKB9f
haddock-interfaces: /usr/share/doc/haskell-crypto-cipher-types/html/crypto-cipher-types.haddock
haddock-html: /usr/share/doc/haskell-crypto-cipher-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypto-cipher-types-0.0.9-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-crypto-cipher-types.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: crypto-cipher-types
version: 0.0.9
id: crypto-cipher-types-0.0.9-2P00NWAGGxtEOd0vR6cD69
key: crypto-cipher-types-0.0.9-2P00NWAGGxtEOd0vR6cD69
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: vincent@snarc.org
stability: experimental
homepage: http://github.com/vincenthz/hs-crypto-cipher
synopsis: Generic cryptography cipher types
description:
    Generic cryptography cipher types
category: Cryptography
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Crypto.Cipher.Types Crypto.Cipher.Types.Unsafe
hidden-modules: Crypto.Cipher.Types.GF Crypto.Cipher.Types.Block
                Crypto.Cipher.Types.BlockIO Crypto.Cipher.Types.Stream
                Crypto.Cipher.Types.OfIO Crypto.Cipher.Types.AEAD
                Crypto.Cipher.Types.Base Crypto.Cipher.Types.Utils
abi: bd4290e338dd0a4b08c0bf6dcca130b0
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/crypto-cipher-types-0.0.9
library-dirs: /usr/lib/ghc-8.0.1/site-local/crypto-cipher-types-0.0.9
data-dir: /usr/share/arm-linux-ghc-8.0.1/crypto-cipher-types-0.0.9
hs-libraries: HScrypto-cipher-types-0.0.9-2P00NWAGGxtEOd0vR6cD69
depends:
    base-4.9.0.0 byteable-0.1.1-15aIBCArSOBEnGxArzrDTM
    bytestring-0.10.8.1 securemem-0.1.9-2y2iWaYcJrVGo5N3TsU2wJ
haddock-interfaces: /usr/share/doc/haskell-crypto-cipher-types/html/crypto-cipher-types.haddock
haddock-html: /usr/share/doc/haskell-crypto-cipher-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
